netapp_ontap.models.application_nfs_properties API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.application_nfs_properties`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationNfsPropertiesSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationNfsProperties object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `backing_storage GET POST PATCH`

    The backing_storage field of the application_nfs_properties.

  `export_policy GET POST PATCH`

    The export_policy field of the application_nfs_properties.

  `ips GET POST PATCH`

    The ips field of the application_nfs_properties.

  `path GET`

    Junction path

  `permissions GET`

    The permissions field of the application_nfs_properties.